==> marray_1.28.0.zip: marray/doc/marrayPlots.R <==
###################################################
### chunk number 1: 
###################################################
#line 106 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
library(marray)
data(swirl) 
maPlate(swirl)<-maCompPlate(swirl,n=384) 


###################################################
### chunk number 2: 
###################################################
#line 129 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
Gcol<- maPalette(low="white", high="green",k=50) 
Rcol<- maPalette(low="white", high="red", k=50) 
RGcol<-maPalette(low="green", high="red", k=50) 


###################################################
### chunk number 3: maImageGb
###################################################
#line 143 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maGb", subset=TRUE, col=Gcol,contours=FALSE, bar=FALSE) 


###################################################
### chunk number 4: maImageRb
###################################################
#line 147 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maRb", subset=TRUE, col=Rcol, contours=FALSE, bar=FALSE) 


###################################################
### chunk number 5: maImageMraw1
###################################################
#line 186 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maM", bar=FALSE, main="Swirl array 93: image of pre--normalization M") 


###################################################
### chunk number 6: maImageMraw2
###################################################
#line 190 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maM", subset=maTop(maM(swirl[,3]), h=0.10,
l=0.10), col=RGcol, contours=FALSE, bar=FALSE,main="Swirl array 93:
image of pre--normalization M for  10 %  tails")  


###################################################
### chunk number 7: maImageSpotCol
###################################################
#line 204 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maSpotCol", bar=FALSE) 


###################################################
### chunk number 8: maImagePrintTip
###################################################
#line 208 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maPrintTip", bar=FALSE) 


###################################################
### chunk number 9: maImageControls
###################################################
#line 212 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maControls",col=heat.colors(10),bar=FALSE) 


###################################################
### chunk number 10: maImagePlate
###################################################
#line 216 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maPlate",bar=FALSE) 


###################################################
### chunk number 11: maBoxplot1pre
###################################################
#line 309 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
boxplot(swirl[,3], xvar="maPrintTip", yvar="maM", main="Swirl array 93: pre--normalization") 


###################################################
### chunk number 12: maBoxplot2pre
###################################################
#line 333 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
boxplot(swirl, yvar="maM", main="Swirl arrays: pre--normalization") 


###################################################
### chunk number 13: 
###################################################
#line 344 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
swirl.norm <- maNorm(swirl, norm="p")


###################################################
### chunk number 14: maBoxplot1post
###################################################
#line 352 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
boxplot(swirl.norm[,3], xvar="maPrintTip", yvar="maM",
	main="Swirl array 93: post--normalization") 


###################################################
### chunk number 15: maBoxplot2post
###################################################
#line 357 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
boxplot(swirl.norm, yvar="maM", col="green", main="Swirl arrays: post--normalization") 


###################################################
### chunk number 16: maPlot1pre
###################################################
#line 463 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
defs<-maDefaultPar(swirl[,3],x="maA",y="maM",z="maPrintTip")

# Function for plotting the legend
legend.func<-do.call("maLegendLines",defs$def.legend)

# Function for performing and plotting lowess fits
lines.func<-do.call("maLowessLines",c(list(TRUE,f=0.3),defs$def.lines))

plot(swirl[,3], xvar="maA", yvar="maM", zvar="maPrintTip",
		      lines.func,
		      text.func=maText(),
		      legend.func,
		      main="Swirl array 93: pre--normalization MA--plot") 


###################################################
### chunk number 17: maPlot1post
###################################################
#line 479 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayPlots.Rnw"
plot(swirl.norm[,3], xvar="maA", yvar="maM", zvar="maPrintTip",
		      lines.func,
		      text.func=maText(),
		      legend.func,
		      main="Swirl array 93: post--normalization MA--plot")

==> marray_1.30.0.zip: marray/doc/marrayPlots.R <==
###################################################
### chunk number 1: 
###################################################
#line 106 "marrayPlots.Rnw"
library(marray)
data(swirl) 
maPlate(swirl)<-maCompPlate(swirl,n=384) 


###################################################
### chunk number 2: 
###################################################
#line 129 "marrayPlots.Rnw"
Gcol<- maPalette(low="white", high="green",k=50) 
Rcol<- maPalette(low="white", high="red", k=50) 
RGcol<-maPalette(low="green", high="red", k=50) 


###################################################
### chunk number 3: maImageGb
###################################################
#line 143 "marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maGb", subset=TRUE, col=Gcol,contours=FALSE, bar=FALSE) 


###################################################
### chunk number 4: maImageRb
###################################################
#line 147 "marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maRb", subset=TRUE, col=Rcol, contours=FALSE, bar=FALSE) 


###################################################
### chunk number 5: maImageMraw1
###################################################
#line 186 "marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maM", bar=FALSE, main="Swirl array 93: image of pre--normalization M") 


###################################################
### chunk number 6: maImageMraw2
###################################################
#line 190 "marrayPlots.Rnw"
tmp<-image(swirl[,3], xvar="maM", subset=maTop(maM(swirl[,3]), h=0.10,
l=0.10), col=RGcol, contours=FALSE, bar=FALSE,main="Swirl array 93:
image of pre--normalization M for  10 %  tails")  


###################################################
### chunk number 7: maImageSpotCol
###################################################
#line 204 "marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maSpotCol", bar=FALSE) 


###################################################
### chunk number 8: maImagePrintTip
###################################################
#line 208 "marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maPrintTip", bar=FALSE) 


###################################################
### chunk number 9: maImageControls
###################################################
#line 212 "marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maControls",col=heat.colors(10),bar=FALSE) 


###################################################
### chunk number 10: maImagePlate
###################################################
#line 216 "marrayPlots.Rnw"
tmp<- image(swirl[,3], xvar="maPlate",bar=FALSE) 


###################################################
### chunk number 11: maBoxplot1pre
###################################################
#line 309 "marrayPlots.Rnw"
boxplot(swirl[,3], xvar="maPrintTip", yvar="maM", main="Swirl array 93: pre--normalization") 


###################################################
### chunk number 12: maBoxplot2pre
###################################################
#line 333 "marrayPlots.Rnw"
boxplot(swirl, yvar="maM", main="Swirl arrays: pre--normalization") 


###################################################
### chunk number 13: 
###################################################
#line 344 "marrayPlots.Rnw"
swirl.norm <- maNorm(swirl, norm="p")


###################################################
### chunk number 14: maBoxplot1post
###################################################
#line 352 "marrayPlots.Rnw"
boxplot(swirl.norm[,3], xvar="maPrintTip", yvar="maM",
	main="Swirl array 93: post--normalization") 


###################################################
### chunk number 15: maBoxplot2post
###################################################
#line 357 "marrayPlots.Rnw"
boxplot(swirl.norm, yvar="maM", col="green", main="Swirl arrays: post--normalization") 


###################################################
### chunk number 16: maPlot1pre
###################################################
#line 463 "marrayPlots.Rnw"
defs<-maDefaultPar(swirl[,3],x="maA",y="maM",z="maPrintTip")

# Function for plotting the legend
legend.func<-do.call("maLegendLines",defs$def.legend)

# Function for performing and plotting lowess fits
lines.func<-do.call("maLowessLines",c(list(TRUE,f=0.3),defs$def.lines))

plot(swirl[,3], xvar="maA", yvar="maM", zvar="maPrintTip",
		      lines.func,
		      text.func=maText(),
		      legend.func,
		      main="Swirl array 93: pre--normalization MA--plot") 


###################################################
### chunk number 17: maPlot1post
###################################################
#line 479 "marrayPlots.Rnw"
plot(swirl.norm[,3], xvar="maA", yvar="maM", zvar="maPrintTip",
		      lines.func,
		      text.func=maText(),
		      legend.func,
		      main="Swirl array 93: post--normalization MA--plot")
